# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aissemble_machine_learning_inference/generated/inference/grpc/generated/inference_payload_definition.proto
# Protobuf Python Version: 4.25.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\njaissemble_machine_learning_inference/generated/inference/grpc/generated/inference_payload_definition.proto\"e\n\x06Record\x12\x19\n\x11source_ip_address\x18\x01 \x01(\t\x12\x0f\n\x07\x63reated\x18\x02 \x01(\x05\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x10\n\x08\x63\x61tegory\x18\x04 \x01(\t\x12\x0f\n\x07outcome\x18\x05 \x01(\t\"3\n\tInference\x12\r\n\x05score\x18\x01 \x01(\x05\x12\x17\n\x0fthreat_detected\x18\x02 \x01(\x08\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aissemble_machine_learning_inference.generated.inference.grpc.generated.inference_payload_definition_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  _globals['_RECORD']._serialized_start=110
  _globals['_RECORD']._serialized_end=211
  _globals['_INFERENCE']._serialized_start=213
  _globals['_INFERENCE']._serialized_end=264
# @@protoc_insertion_point(module_scope)
